@@ -330,11 +330,11 @@ readlink() places the contents of the symbolic link path in the buf buf, which h
 
 See the L<readlink|https://linux.die.net/man/2/readlink> function in Linux.
 
-=head2 readlinkp
+=head2 get_readlink_buffer_size
 
-  static method readlinkp : string ($file : string);
+  native static method get_readlink_buffer_size : int ($path : string);
 
-The same behaivior of Perl's L<readlink|https://perldoc.perl.org/functions/readlink> function.
+Gets the L</"readlink"> needed buffer size.
 
 =head2 opendir
 
