@@ -22,6 +22,20 @@ C<Sys::IO::FileStream> is the class for the C<FILE> type in C<C language>.
 
 This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
 
+=head1 Fields
+
+=head2 closed
+
+  has closed : ro byte;
+
+The file stream is closed.
+
+=head2 no_need_free
+
+  has no_need_free : ro byte;
+
+The file stream is not needed to be freed.
+
 =head1 Instance Methods
 
   method DESTROY : void ();
